@@ -3,7 +3,7 @@ package MaxMind::DB::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000005';
 
 use 5.010000;
 
@@ -41,7 +41,7 @@ MaxMind::DB::Reader - Read MaxMind DB files and look up IP addresses
 
 =head1 VERSION
 
-version 1.000004
+version 1.000005
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Greg Oschwald Ran Eilam William Stevenson
+=for stopwords Greg Oschwald Mateu X Hunter Ran Eilam William Stevenson
 
 =over 4
 
@@ -178,6 +178,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mateu X Hunter <hunter@missoula.org>
+
+=item *
+
 Ran Eilam <reilam@maxmind.com>
 
 =item *
